Method: Thor::Group.desc
- Defined in:
- lib/github_cli/vendor/thor/group.rb
.desc(description = nil) ⇒ Object
The description for this Thor::Group. If none is provided, but a source root exists, tries to find the USAGE one folder above it, otherwise searches in the superclass.
Parameters
- description<String>
-
The description for this Thor::Group.
16 17 18 19 20 21 22 23 |
# File 'lib/github_cli/vendor/thor/group.rb', line 16 def desc(description=nil) @desc = case description when nil @desc || from_superclass(:desc, nil) else description end end |